// java wrapper for vtkTransmitUnstructuredGridPiece object
//

package vtk;
import vtk.*;

public class vtkTransmitUnstructuredGridPiece extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCreateGhostCells_4(int id0);
  public void SetCreateGhostCells(int id0)
    { SetCreateGhostCells_4(id0); }

  private native int GetCreateGhostCells_5();
  public int GetCreateGhostCells()
    { return GetCreateGhostCells_5(); }

  private native void CreateGhostCellsOn_6();
  public void CreateGhostCellsOn()
    { CreateGhostCellsOn_6(); }

  private native void CreateGhostCellsOff_7();
  public void CreateGhostCellsOff()
    { CreateGhostCellsOff_7(); }

  public vtkTransmitUnstructuredGridPiece() { super(); }

  public vtkTransmitUnstructuredGridPiece(long id) { super(id); }
  public native long   VTKInit();

}
